# Analysis in Literary History {#sec-analysis-lithist}

_Artjoms Šeļa (Kraków)_

## The Trend Line

If there is one method that unites diverse body of works in computational literary history, it must be a trend line. A plot with a line that is tracing change (or continuity) in some derived textual or bibliographical feature over time became the central device for making arguments and telling coherent stories about literary history at large and small scales. Decline of abstract lexicon in fiction [@heuser_2012_quantitative], continuity in genre classification strength over centuries [@underwood_2017_life], long-term stability of Ancient Greek literary style @storey_2020_two, rise of dialogue share [@sobchuk_2016_evolution] and ‘dialogism’ scores [@muzny_2017_dialogism], increase of linguistic repetition [@gemma_2015_operationalizing], expansion and saturation of literary and publishing markets [e.g. @bode_2012_reading], increase in character network complexity [@krautter_2020_schritt] and the fall of dramatic protagonist [@algee-hewitt_2017_distributed], numerous keyword and topics trajectories (through one work, one author’s lifetime, or large corpus). Different studies, relying on different information sources, text analysis procedures, historical and theoretical assumptions. What unites them is time which has a constant appearance as an X-axis on which different trends, bins, lines and curves unfold.

Inferring the trend in data — the average chronological direction of whatever variable currently sits on a Y-axis — in computational literary studies is routinely done with linear regression models that estimate the linear relationship between a response variable and time (y \~ x; Feature \~ Time). A regression line is then superimposed on empirical observations: an upwards slope will show an average linear rise of the Feature per unit of time, a downwards slope — average linear decline. When data follow clearly non-linear trajectories, researchers usually engage in curve-fitting: they use of exponential functions [@heuser_2012_quantitative] or polynomials of different degrees [@gemma_2015_operationalizing; @trilcke_2016_theatre]; they rely on smoothing functions (often unspecified) that follow changes in data locally [Generalized Additive Models, Local regression @underwood_2012_emergence; @underwood_2018_transformation; @krautter_2020_schritt; @pianzola_2020_cultural] or rolling means or medians [@erlin_2017_topic; @sharmaa_2020_rise]; they look at averages in a binned time over 2, 5, 10-year bins [@bode_2012_reading; @sobchuk_2016_evolution] or eyeball empirical distribution of features through time.

What is central to the vast majority of observed studies is that linear models and smoothing functions are used as a simple trend-revealing technique, almost as a rhetorical (’see, this is _clearly_ what is happening with this data in time’), not a statistical device. Indeed, literary history and causal inference are yet to stand together. With few exceptions, explicit statistical modeling that tries to tease out different factors that influence the distribution of a feature of interest, if it happens, happens _outside_ of dimension of time. So et al. [@so_2018_race] use logistic regression to show a higher probability of Black writers using Bible citation in a social context; @koolen_2018_reading in her thesis models factors (gender, genre, being a translation) that might influence people judgement about literary quality; @manjavacas_2020_statistical build bi-variate (outcome is coming from two predicted variables) model with group (or ‘random’) effects to estimate the relationship between quotation use in Patrologia Latina and surrounding topical context.

Exceptions include early work in literary sociology by @vanrees_1996_event: authors engage with discrete-time event history models (also known as ‘survival’ models) to understand writer’s debutes and factors that shape their reputation, measured by number of reviews. Essentially, they build a logistic regression for estimating a probability of increase in the number of reviews, but where each variable is allowed to change states at discrete events (i.e. publishing a new book). The advantage of using a survival model (which also pushes authors to bin count variables, like number of reviews, into discrete categories) over simpler multiple regression is not apparent from the study, but this research embraces complex modeling of change, unusual in the current CLS landscape.

More recently, @jockers_2013_macroanalysis and @underwood_2022_cohort treated time not as a neutral dimension that carries (and reveals) change, but as a factor of data. Jockers fit hundreds of independent linear regressions (one per predictor per textual feature) and tabulated statistically significant (based on p-values) results to estimate to which extent different factors — time, gender, genre, author — can describe observed similarities between texts. @underwood_2022_cohort used a similarly designed barrage of linear models (relying, instead, on the measure of explained variance, $R^{2}$) to argue that birth year, or generation, of authors, explains change in literary topics better than publication year, thus revealing a cohort effect in literary history. Additionally, their study asks how the use of topics change during individual careers. Do authors continuously ‘update’ topic use through their lifetimes, or use them somewhat consistently, according to some random baseline? Their research compares two processes with structural equation models that treat books as discrete events (similarly to Rees and Vermunt). On average, they find that topics that are driven by generation effects tend to reoccur in authors without a clear trend of usage, and topics that are resulting from specific historical times (war and other localized events) tend to be updated, revealing rising and falling patterns.

When it comes to detecting change in the usage of keywords or topics over time, @wadsworth_2016_evolution proposed a series of stand-out methods to trace the evolution of vocabulary. They focus on Sylvia Plath and look at cumulative distribution of each word through her works over time. The authors fit two simple functions to a cumulative trend — a linear and a power law. Using fits of two curves and differences between them, the study identifies groups of words with similar behavior: those that are used consistently over time, and those that are accelerating, or decelerating. Additionally, by looking at distribution of word-onset times (times before which Plath did not use a word regularly), the authors find clusters of words that only appear in specific periods and can potentially discriminate shifts in poet’s style, or aid periodization.

We spent more time with these cases, because they present a more nuanced approach to chronology than simply fitting linear trends to data. The fascination with trend lines was already critiqued conceptually by @moretti_2019_hidden: the authors note that trends smooth over complicated cases, conceal non-linearity and "remove conflict from history". Even if the line is smooth and monotonous, the forces that generated it might not be. Additionally, there are purely technical considerations. Out-of-the-shelf usage of linear models introduces the usual pitfalls known from other disciplines: over-reliance on significance testing (p-values) and explained variance ($R^{2}$) in the reporting instead of explicit statistical modeling; using linear regression, tied to the normal distribution, to model unsuitable data like discrete counts, probabilities and ratios, which can introduce unreasonable predictions — negative ratios, or probabilities larger than 1 [see @winter_2021_poisson for a relevant discussion of using the Poisson distribution for modeling counts in linguistics].

A reliance on linear trend lines can also negatively impact the representation of uncertainty in the results when lines are fit on top of aggregated data: yearly averages and medians [e.g. @trilcke_2016_theatre; @muzny_2017_dialogism; @underwood_2012_emergence; @sela_2017_shortest]. The resulting ’average of averages’ line is fitted on a handful of yearly observations, conceal value dispersion and overemphasize trend direction in time. If the purpose of linear models is just demonstrating the trend, using empirical values together with indication of range of their distribution, or bootstrapped confidence intervals @sharmaa_2020_rise might, in many cases, be a much more direct and transparent approach.

Overall, the analysis of chronological change and continuity in CLS is in the early stages of development. When compared to sophisticated text analysis, annotation and representation techniques, it is apparent that the dimension of time is a pretty much open methodological and conceptual problem.

## Inferring historical relationships between texts

Chronological trends can be ubiquitous and useful, but they usually do not make any judgement about historical connections between data points, which is another large subfield of (computational) literary history. Which texts are connected through influence, citation and rewriting? Can similarity be used to also infer genealogy? How known manuscripts or editions of a text are related? These questions belong to the domain of intertextuality, and the main methodological domain of intertextuality, at least in CLS, is text reuse detection — techniques of tracing matching parts between texts.

### Difference and similarity

@seo_2008_local identify two major approaches to text reuse detection: string-based methods and similarity-based methods. While calculation of similarity (or distance) between full texts is rarely considered to specifically be a text reuse method, some studies (explicitly or implicitly) rely on language-based similarity to make arguments about influence and infer pathways of intertextuality. @jockers_2013_macroanalysis constructs networks based on pairwise stylistic similarities between texts and then identifies most influential texts as the most central nodes. A similar goal — of tracing patterns of stylistic similarity beyond authorship — is pursued by @eder_2017_short in the so-called bootstrap consensus networks. @broadwell_2017_confusing use heatmaps based on distance matrices to understand boundaries of Modernism in Scandinavian literature — they use areas of overarching (dis-)similarity between books to argue about periodization. @iwata_2012_tracing directly equates text similarity with historical relationships when dealing with collections of Japanese Noh plays. This equation is always a considerable leap of faith — there is no guarantee that similarity in frequency distributions of linguistic elements would also signal any kind of historical relationship. Stylistically central texts might be just the closest texts to an unobserved ‘average’ language — simultaneously similar to many, but related to none.

Recently, more attention was drawn to non-symmetrical measures of difference [@barron_2018_individuals; @chang_2020_divergence] based on divergence. Divergence (specifically Kullback-Leibler divergence, KLD) measures the amount of ‘surprise’ of encountering a probability distribution P, given a prior probability distribution Q. Texts are usually represented as probability distributions over inferred topics (e.g. LDA) to keep divergence measures interpretable. Difference between P → Q and Q → P can, for example, signal an enclosement relationship, when one texts covers more ground than the other, topically focused and narrow. It is more surprising to encounter the general text having seen only the focused one, than the other way around.

It is argued that asymmetry in KLD is a good fit for modeling cultural point of views and their inherent subjectivity [@chang_2020_divergence]. In relation to historical data, KLD was used to derive measures of novelty and resonance: the former describes how surprising is a text T given the past, the former describes how persistent is information from a text T in the future. High-novelty high-resonance texts introduce innovations that also leave their mark on the future. These measures were originally used to detect a novelty bias in the debates of the first revolutionary French Assembly [@barron_2018_individuals] and recently extended to various historical cases, including the detection of events in Dutch chronicles [@lassche_2022_chronicling]. The divergence-based framework provides an alternative approach to trends, focusing on uncovering relative, context-dependent positions of data points in time. The question of historical relationships between these points, however, remains open.

### Text reuse and alignment

When two texts share matching or very similar fragments, it provides better ground for establishing (or suspecting) an intertextual link. The majority of text reuse research focuses on string matching: either for discovering potential quotations for future work and integration with search engines [@roe_2016_digging; @sturgeon_2017_unsupervised; @janicki_2022_exploring], or deriving text reuse scores to understand the intensity of text reuse between documents [@bernstein_2015_comparative; @gawley_2017_comparing; @shang_2021_improving].

There are numerous solutions and existing frameworks [like Tesserae @coffee_2012_tesserae; Tracer @buchler_2014_historical; Passim @smith_2014_detecting; Text Matcher @reeve_2020_textmatcher] of text reuse detection. Most of them focus on matching literal, or near-literal, repetitions of strings that can be relatively easy solved by n-gram matching and sequence alignment algorithms that build up similar regions from local matching units. Many of the approaches originate in bioinformatics and are a part of the longest common substring problem [see @olsen_2011_something]. In literary studies, identified string matches are often weighted (e.g. by TF-IDF) to distinguish ‘interesting’ matches based on document-specific words from simple linguistic repetition [@bernstein_2015_comparative; @shang_2021_improving].

Tracing non-literal intertexts — like allusions — that are invoking the source text through a paraphrase, development of a shared theme or semantics is more difficult and rare [for an overview see @manjavacas_2019_feasibility]. Detection of allusions is an open interpretative practice: there is little ground-truth data available, because there is little scholarly agreement available, which complicates the adjustment of formal techniques to non-literal cases of text reuse. The nature of the problem that shifts the focus from lexical correspondence to semantic overlap, invites injecting semantic information into reuse detection. 

@manjavacas_2019_feasibility – using a subset of manually identified Biblical allusions in writings of Bernard of Clairvaux – show that hybrid methods that combine both lexical and semantic information have the best performance in retrieving allusion sources. Specifically, they use the _soft cosine_ that incorporates word similarity information directly into the cosine distance (which is calculated using bag-of-words vectors): the method can trace non-trivial similarities between target and source text.

Text reuse also poses a specific challenge to folklore studies that deal in large archives of written records of oral song performances. Automatic navigation through these archives is complicated because of high degree of textual variation, despite the large parts of the records are repeating on different levels. All texts, in principles, are related through a shared oral tradition, which conditions the reproduction of formulas and motifs, arrangement of parts and transmission of texts. Recent work by @janicki_2022_exploring shows that simple character bigram similarity of verse lines can be effectively used to identify ‘equivalent verses’ – clusters of very similar strings. The study proceeds to align different texts in the collection using _cluster indices_ instead of actual strings, which is aimed to generalize from strings to their _types_ and serves as a good foundation for inferring similarity between folklore records with lots of variation. Poetic form makes the task somewhat simpler, since it provides a natural discrete ‘unit’ of text — a line, but this study is a promising development on the path of intertextual generalization.

### Trees

A geneticist and one of the founders of cultural evolution, Cavalli-Sforza (with P. Menozzi and A. Piazza) wrote that "a tree can be viewed as a simplified description of a matrix of distances" [@cavalli-sforza_1994_history, p. 33]. Distances between anything: cities, species, languages, or individual texts. CLS routinely relies on dendrograms (that are built by grouping closest pairs in a distance matrix) as tools of unsupervised clustering. We are interested in a pattern of similarities and dissimilarities: which texts sit at the closest branches (maybe written by one author?), which texts form distinct clusters (maybe belonging to one genre?). These trees are not usually assuming any _historical_ relationships between the leaves, which was the original purpose of a tree as a model: to sort out a history of life. Thus, the majority of CLS trees are not phylogenies and are of little interest to literary history.

Here we instead focus at the trees that _are_ phylogenies and assume the descent with modification as a primary mechanism that produced its objects. There are at least three areas where phylogenetic methods or thinking is used in relation to (literary) texts:

1. Literary morphology. @gasparov_1996_history reconstructed branching and merging history of European verse forms, while @moretti_2005_graphs used a tree model to manually chart histories of clues in detective fiction and free indirect discourse.
2. Oral traditions: several groups of anthropologists use phylogenies to study branching of folktales [@tehrani_2015_oral; @dasilva_2016_comparative] and mythological motives [@thuillard_2018_largescale], an analysis that also opens connections to evidence coming from human migration history, paleogenetics and archaeology.
3. Paleography and codicology explicitly engages with phylogeny reconstructions: copies (or witnesses) of a manuscript are all related, but usually it is hard to tell how exactly: the historical record, similarly to archaeological one, is fragmented, incomplete; it needs hypothetical reconstruction. To do this, one can use accumulation of errors and changes in copies that, not unlike genetic sequences, reflects transmission history. Similarity between documents here _can_ signal common origins. Use of phylogenetic trees in inferring relationships between manuscript copies is a modern extension of a stemmatology — manual philological reconstruction of manuscript histories [see recent handbook, edited by @roelli_2020_handbook].

Phylogenetic methods provide two clear advantages: automatic alignment (compare texts) and automatic inference of relationships (build a tree as a possible history). Phylogenies of texts started with relying on manual coding of traits: to test relationships between manuscripts of the _Canterbury Tales_ [@barbrook_1998_phylogeny], or reconstruct history of branching of _Little Red Riding Hood_ [@tehrani_2013_phylogeny]. Recently, sequence alignment is used more frequently for comparing strings of texts directly, as in the case of phylogeny of print editions of _The Wandering Jew’s Chronicle_ [@bergel_2015_lines].

Phylogenetic methods that originated in evolutionary biology obviously have design problems when used with cultural  textual data: all ‘ancestors’ are thought to be unobservable (what we have is only ‘leaves’ of the tree) and often methods assume strong vertical transmission (like maximum parsimony trees, that rely on minimizing independent mutations). Manuscript transmission simulated in the lab [@spencer_2004_phylogenetics], however, shows that these trees can still be useful and reflect historical clusters faithfully, but are not able to represent known ancestry relationships. Several methods outside of maximum parsimony trees were adopted that do not expect vertical transmission in data, e.g. split decomposition and, more recently, network-based approaches such as Neighbor-Net [@iwata_2012_tracing; @bergel_2015_lines]. Few alternatives to phylogenetic framework as a whole were also proposed: @andrews_2012_trees model stemmata and witness readings as directed acyclic graphs, or DAGs, also used in causal inference — to utilize the formal approach, but escape the assumptions of evolutionary biology.

Since anthropologist Alfred Kroeber’s critique in early 20th century, evolutionary trees are often dismissed as incompatible with with cultural histories where there is no reason to expect a strong tree-like signal: after all, culture mashes and mixes branches together. However, this is a misconception about evolution: branching, tree-like phylogenies are characteristic only for vertebrate evolutionary histories. Culture is more akin to viruses and bacteria with extensive horizontal exchange of information (and still, for various reasons, can be very tree-like, not fundamentally different from biological evolution [@durham_1990_advances; @collard_2006_branching]. From adjacent disciplines we also see the expanding use of unrooted, network-based methods that do not assume a strong tree-like pattern in the transmission process: one such example can be the use of dynamic phylogenetic networks with community inference to trace histories of interacting individuals in electronic music [@youngblood_2020_phylogenetic]. Patterns of collaborations produce distinct subgenres of music that stay recognizable despite an increase in transmission between branches in the age of internet.

## Conclusion

We centered this survey on two areas of analysis that, we think, are indispensable for _historical_ inquiry. First, usage of trends and trendlines deal with _describing_ change: we see vast array of techniques and applications, but most research mainly stays at curve-fitting step and rarely engages in explicit causal inference. Second, distances, text reuse techniques and trees — all try to _infer_ relationships between texts, often under historical assumptions that can be further used to reconstruct lineages of texts, traditions, or forms.

## References {.unnumbered .unlisted}

See [works cited and further reading](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_analysis-lithist/collection) on Zotero.

## Citation suggestion  {.unnumbered .unlisted}

Artjoms Šeļa (2023): "Analysis in Literary History". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/analysis-lithist.html](https://methods.clsinfra.io/analysis-lithist.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{sela_2023_analysislithist,
  title = {Analysis in Literary History},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {Šeļa, Artjoms},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/analysis-lithist.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 

