# What is Authorship Attribution? {#sec-what-author}

_Joanna Byszuk (Kraków)_

## Introduction

Authorship attribution can be simply explained as a study whose goal it is to answer the question: who is the author of some text we examine?  

Nowadays, non-traditional, computational or stylometric authorship attribution or stylometry for short – as it is also often called to distinguish it from more long-standing, philological methods of authorship attribution – is one of the more popular tasks in Natural Language Processing and Computational Literary Studies or even a subdiscipline on its own, but its roots are deep in the past. The questions “is this text authentic? was it really written by this person?” and “I wonder who could have authored this unsigned or otherwise anonymous text” have probably been accompanying humans since the beginning of written communication. In fact, some of the early approaches to authorship attribution that we know of use methods very much like the ones we apply today. For example, in 1851, Augustus De Morgan suggested that Biblical authors could be identified by the features of their writing, which was also used in early stylometric ventures dedicated to the study of the chronology of texts, verifying whether a text was falsified, etc.  

A very similar method was used by Frederick Mosteller and David Wallace in their study [@mosteller_1963_inference] of *The Federalist Papers*, a famous collection of essay pamphlets published by a trio of American forefathers: Alexander Hamilton, James Madison, and John Jay, to promote the new Constitution. Using frequencies of selected words from the essays and analyzing them with a Bayesian-based method, they identified the author of twelve Papers, the authorship of which had been disputed earlier. While their method had its faults and better ones have been developed since, Mosteller and Wallace are and will be remembered as pioneers in computational authorship attribution.

## Authorship Attribution or Verification?

There are two distinguishable types of authorship examination – attribution and verification [@koppel_2009_computational].

Authorship attribution typically concerns the so-called closed set problems, that is all inquiries in which the real author must be one of the finite, known, set of candidates. Think of *The Federalist Papers* as the perfect example – a collection of 85 articles and essays written by three founding fathers whose names are well known to us: Alexander Hamilton, James Madison, and John Jay. While an extremely skeptical person could argue it is impossible to know if they didn’t have another anonymous co-writer unknown to the history, no evidence points to such a scenario and it is safe to assume that 12 letters of long disputed authorship must have been written by one of these three. In the case of closed sets, the focus is on distinguishing between individual candidates’ stylistic fingerprints and finding out which of them best fits the disputed text.

On the contrary, authorship verification usually concerns the so-called open set problems, that is all inquiries in which there is some suspicion over possible authors, usually based on philological evidence, but the possibility that the real author is not actually included in the corpus cannot be excluded. This kind of situation can result from many factors, such as many possible writers (especially in under-researched problems), little data available, and finally, the possibility that no other texts by the real author are preserved (or that the author completely hid themself under a pseudonym) and so cannot be included in the reference corpus.

While both have been applied in numerous stylometric investigations, attribution obtains significantly more attention in applications [starting with @mosteller_1963_inference] and review of methods [@grieve_2007_quantitative; @stamatatos_2009_survey; @evert_2017_understanding] than verification, with the latter approach developing more intensely only in the last decade or so [e.g. @koppel_2004_authorship; @kestemont_2016_authorship; @halvani_2019_assessing].

## Tools for Authorship Attribution

The most widely-used tool in stylometric authorship attribution is [stylo](https://computationalstylistics.github.io/) [@eder_2016_stylometry], as it provides users with the choice between a simple graphical user-interface and a command-line interface, implements most currently-used methods of stylometric authorship attribution (many of which can also be used in applications beyond authorship attribution), is continually developed and has been popularized through more than a decade's worth of introductory and advanced workshops by the developers. Another well-established tool for authorship attribution is [JGAAP](https://evllabs.github.io/JGAAP/) (Java Graphical Authorship Attribution Program). 

## References {.unnumbered .unlisted}

See [works cited and further readings](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_what-author/library) on Zotero. 

## Citation suggestion  {.unnumbered .unlisted}

Joanna Byszuk (2023): "What is Authorship Attribution?". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/what-author.html](https://methods.clsinfra.io/what-author.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{byszuk_2023_authorship,
  title = {What is Authorship Attribution?},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {Byszuk, Joanna},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/what-author.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 
