# What is Canonicity? {#sec-what-canon}

_Lisanne van Rossum, Karina van Dalen-Oskam (Amsterdam)_

## Introduction: canon and canonicity

The word ‘canon’ goes back to the biblical canon, a collection of scriptures that solidify authoritative doctrine in Christianity. Analogous to the biblical canon the literary canon is generally understood as the traditional curriculum of literary texts [@guillory_1993_cultural, p. 6], or in somewhat more detail "a constellation of highly valued, high-cultural texts that have traditionally acted as arbiters of literary value, determining the discipline of literary studies as well as influencing the critical and cultural reception of literature." [@mukherjee_2017_canonicity]. The literary canon is also used more broadly as a reference to  works with literary connotation [@harris_1991_canonicity, 110]. Key is that the canon is a selection, a small sub-set of everything published, and reflects the literary prestige the texts have in the eyes of readers, critics, publishers, fellow-writers, and teachers. It is important to keep in mind that relative cultural meanings of both canonicity and prestige exist – and flourish – in all kinds of textual spaces, for example in fan fiction [@chin_2018_it, p. 250].

Harris posited that the literary canon may shift in its exact composition and position, but that the purposes of the literary canon are distinct and worth further investigation [@harris_1991_canonicity, p. 110]. Forty years down the road, national literary fields now call for renewed evaluation of the contemporary relevance and validity of the hegemonic canon, with special focus on whose interests the canon should reflect. The canon is selective and inherently defined both by what it contains and what it excludes. The current literary canon, Karina van Dalen-Oskam observes, is the product of systemic prescription and re-inscription of prestige [@vandalen-oskam_2021_het]. Contemporary debates are centred on the democratization of the canon such as collective reading initiatives in the United Kingdom;^[See e.g. Libraries Connected’s [The Novels that Shaped Our World](https://www.librariesconnected.org.uk/resource/novels-shaped-our-world-libraries-programme-evaluation-report-pdf) programme] on reflection on a culturally descriptive canon through a reader survey in The Netherlands [@koolen_2020_literary; @vandeinsen_2022_nederlandstalige]; on the formation of the nation state through politicized canonization efforts in Belgium [@tollebeek_2022_een]; and on the potential of the canon to bring minority perspectives into view, such as in Germany [@meyer_2021_questioning].

## Analysing canonised and non-canonised texts

Textual analysis of the literary canon has fundamentally changed since the digital turn. In practice this means that researchers no longer need to limit their analysis to a small selection of literary texts. Pioneering work was done by Matthew Jockers in his analysis of a corpus of 19th-century English-language novels [@jockers_2013_macroanalysis] and at the Stanford Literary Lab, which dedicated at least three of their influential Pamphlets to large-scale analysis of literary text corpora, considering both canonicity and prestige in their approach [@algee-hewitt_2015_canon; @algee-hewitt_2016_canon; @porter_2018_prestige]. Jodie Archer and Matthew Jockers gathered a corpus of novels on the New York Times’ Best-seller list to explore the differences between these novels and those that did not reach the same level of popularity, also taking into account different levels of literary prestige [@archer_2016_bestseller]. Mass digitization of library holdings offers the opportunity to make larger and different selections of texts and an enlarged repertoire of options to study them, as Ted Underwood stated. "Instead of arguing about samples as if they were competing canons, we can adopt a relational mode of reasoning about literary history, akin to the methods of social science" [@underwood_2019_distant, p. 177]. 

Social constructivist theories of prestige as cultural capital revolved around the question of who or what creates prestige, focusing not on the art works themselves but on sociological processes. In his work The Field of Cultural Production, Bourdieu outlines three sources of distinction, or “three competing principles of legitimacy”: artists’ in-group approval, ‘consecration’ by the institutions of the dominant elite, and a moderate amount of popular success [@bourdieu_1996_field, 50-51]. In turn, Gramsci countered that artistic approval is much more slippery than Bourdieu presented, as the peer group is relative to each author and their intentions [@gramsci_1991_selections]. Guillory argued that ‘the school’ in the sense of the Academy is the main factor in creation of cultural capital and canonicity [@guillory_1993_cultural]. Despite these expansions on Bourdieu’s conceptualization of distinction as a diffuse market of exchange between forces and actors in the literary field, the art work itself was not systematically inserted back into models of prestige until De la Fuente and others proposed the New Sociology of Art [@delafuente_2007_new]. 

In line with this New Sociology, recent academic inquiry into perceptions of literariness has shifted towards a more integrated approach of both textual analysis and large-scale study of literary value judgments in the project _The Riddle of Literary Quality_ [@koolen_2020_literary; @vandalen-oskam_2023_riddle]. Modelling prestige in this way can give way to quantitative discussion of those textual properties that are associated with prestige within different temporal and spatial contexts, as exemplified by Van Cranenburgh’s work on literary language in the Dutch market [@vancranenburgh_2016_rich]. As suggested by Ted Underwood, consciously modelling with rather than against the bias of a corpus can also present new comparative opportunities for Digital Humanities research [@underwood_2021_can]. Acknowledging the historically specific nature of a language model, for example, allows us to evaluate how a seminal novel from the past would have performed today.
Indexing canonicity over time and place can trace developments and changes in cultural value placements, an approach taken by Royal Academy of Dutch Language and Literature’s Canon Festival and the sister projects The Riddle of Literary Quality by the Huygens Institute for History and Culture of the Netherlands and the Novel Perceptions: Towards an Inclusive Canon project from the University of Wolverhampton.

Another approach to canonicity combines an analysis of the language used in the texts’ reception, such as commercial reviews, academic papers and publications, and public Tweets or Goodreads reviews, with that of the texts themselves, as investigated by the Impact and Fiction project by the Huygens Institute for History and Culture of the Netherlands.

## Conclusion

The literary canon is formative in all stages of cultural production and reception: it contributes substantially to defining what is written, published, read, reviewed, appreciated, and archived. As such, understanding the canon will lead to increased understanding of those texts that are available for computational analysis, either in digitized source material or as a node in a network of sources surrounding a text. 

## References {.unnumbered .unlisted}

See [works cited and further readings](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_what-canon/library) on Zotero. 

## Citation suggestion  {.unnumbered .unlisted}

Lisanne van Rossum, Karina van Dalen-Oskam (2023): "What is Canonicity?". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/what-canon.html](https://methods.clsinfra.io/what-canon.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{vanrossum_2023_canonicity,
  title = {What is Canonicity?},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {van Rossum, Lisanne and van Dalen-Oskam, Karina},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/what-canon.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 

