# What is Gender Analysis? {#sec-what-gender}

_Evgeniia Fileva (Trier)_

## Gender studies as a field

Gender studies as a field investigates the ways in which gender is manifested in society, especially the cultural aspects that define one gender or another [@schoessler_2010_einfuehrung]. Gender studies usually begins with a reference to the difference between gender and sex. Scholars agree on the following way of distinguishing these concepts, namely they believe that sex is a biological category that is by nature dimorphic, while gender is learned behavior that is influenced by social factors. In the context of the feminist approach, gender is not a dichotomous category, and gender boundaries are very blurred and difficult to define [@talbot_2019_language; @butler_1990_gender]. @talbot_2019_language sees gender as a continuum in which there are different degrees of femininity and masculinity that apply to both genders. @butler_1990_gender believes that gender can be a "free-floating artifice". In CLS, however, the dichotomy of masculine/feminine is usually used because it is easier to implement, as @koolen_2018_reading argues.

## Gender in literature

Gender studies is an interdisciplinary field that explores the impact of gender on various aspects of our lives. Although at first glance gender studies has much in common with sociology, this research field has a major role in literary studies. Literature from the perspective of gender studies examines authors, their personalities and authorial style, and characters, their behavior and speech markers that support or refute gender stereotypes.

Gender stereotypes is a problem which is mentioned in almost all the works we found on the topic of gender studies in the literature. Stereotypes are understood as social constructs of gendered behavior [@jockers_2017_understanding], which scholars try to define in the context of a particular time period. For instance, in the Victorian period, women and men in society were assigned clearly defined social roles. While men were seen as proactive doers, women's position was primarily passive and submissive [@jockers_2017_understanding]. Such stereotypical gender traits are quite a strong conceptual construct, which has been formed and reinforced in society over long periods of time. Some stable stereotypes in the sphere of women's influence are such concepts as home, children, family, maternity, small spaces (kitchens, rooms in the house), as well as the whole sensual sphere, as opposed to "male" rationality and logic [@weidman_2017_limits]. These stereotypes led to the fact that typically female themes, which are mostly expressed in sentimental novels, were considered a "low genre" and did not become canonised. In addition, critics spoke quite negatively about women's writing, making no secret of their dismissive attitude. As a consequence, not only were women's novels published less frequently, but they were also less likely to win literary prizes, directly affecting the perception of women as writers [@koolen_2018_reading]. (On the relationship between gender, genre and canonicity, see also the chapter on "What is Canonicity and Prestige?", @sec-what-canon.)

One of the difficulties of gender-based research is that gender in the modern tradition is not a binary structure with clear boundaries. In the research literature, the concept of gender is closer to the biological concept of gender – that is, a binary structure where there are male authors and female authors [@jockers_2017_understanding; @koolen_2018_reading].

Another problem raised in many studies is the difficulty of determining the gender of the author, since there are uncertain cases. For instance, a woman could publish under a man's name (e.g. George Sand), a man wrote under a woman's name (e.g. Suzanne Vermeer), or it is difficult to understand the author's gender from a pseudonym. In these cases, stylometric methods of determining authorship and author gender are being implemented. There is also a case when the author is transgender (e.g. Maxim Februari), which makes it problematic to classify the author into one category or another [@koolen_2018_reading].

## Research and approaches

As a rule, the focus of gender studies in the literary context is style features and authorial markers, stylometry, comparison of gender representation (usually female) in literary works of different time periods, evolution of "women's literature," gender balance in literary corpus, etc.

Scholars extrapolate their findings more broadly to the social context and attempt to answer such questions as whether there is discrimination against female authors, novels and/or characters [@koolen_2018_reading; @jockers_2017_understanding] or what distinguishes female literary style from male [@rybicki_2015_vive; @weidman_2017_limits].

We cannot fail to mention @koolen_2018_reading, who has done a seminal study of Dutch literature with a focus on the relationship between the author's gender and the perception of his or her literary work. She explores the so-called "prestige" and the path to literary acceptance, as well as its dependence on the author's gender. Koolen shows that gender and prestige or canonicity are closely related.

While the above-mentioned works relate to the author's gender, there are studies of gender tendencies in literary characters. For example, @jockers_2017_understanding have studied the relationship between the actions and personality of characters in 19th-century works and their gender. @underwood_2018_transformation conducts a broader study of late 18th- and early 21st-century English-language literature. The focus of his research is on the conventional roles of characters that are dictated by their gender. He examines how much attention authors paid to female and male characters and what the distribution of roles looked like in several centuries of literature. In terms of the method of such research, parsing, namely recognizing characters in the text as well as the context in which they appear, plays a major role.

## References {.unnumbered .unlisted}

See [works cited and further reading](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_what-gender/library) on Zotero. 

## Citation suggestion  {.unnumbered .unlisted}

Evgeniia Fileva (2023): "What is Gender Analysis?". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/what-gender.html](https://methods.clsinfra.io/what-gender.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{fileva_2023_gender,
  title = {What is Gender Analysis?},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {Fileva, Evgeniia},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/what-gender.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 

