# What is Genre Analysis? {#sec-what-genre}

_Christof Schöch (Trier)_

## Introduction: The theory of literary genres

Literary Genre Analysis investigates literary texts from the perspective of the genre(s) or subgenre(s) they participate in. As a consequence, genre analysis in CLS operates against the backdrop of both an extensive body of theories of genres and subgenres in established literary history, and a no less extensive body of studies on the characteristics and the history of specific literary genres and subgenres.     

Arguably, the nature of and distinctions between literary genres is one of the oldest problems of literary theory, going back at least to Aristotle, who thought of genres as categorical classes that are mutually exclusive and clearly delimited based on specific criteria. For example, narrative and dramatic forms are distinguished based on whether or not the speaker is a part of the represented world or not. Based on such classificatory thinking, hierarchical systems of genres and subgenres were pursued, where each class has a _differencia specifica_ relative to other, related classes. 

Many different perspectives on genre have been developed by literary theorists and literary historians over time. As Matthew Wilkens writes, mentioning several key perspectives: "For critics in the mold of Northrop Frye, genre is a formal category having to do with the 'radical of presentation' through which plot-level events are portrayed; for Gérard Genette, it involves primarily content-level differences within formally defined modes; for Raymond Williams, genre is part of a “social language” that unites distinct aspects of the social and material processes that make up a cultural situation" [@wilkens_2017_genre, p. 2]. 

Starting in the 1970s, in addition, the categorical approaches were questioned more radically and alternative and more flexible models of literary genre were proposed [see e.g. @hempfer_1973_gattungstheorie; @hempfer_2014_aspects]. Prominent examples include, for instance, genres as groups of works linked by _family resemblance_ (in the tradition of Wittgenstein), or genres as _prototypical_ categories (in analogy to prototype theory in biology and cognitive psychology). These approaches have in common that an individual work can participate in a given subgenre to a larger or lesser degree, and can participate in more than one genre to varying degrees. Both José Calvo Tello and Ulrike Henny-Krahmer have pursued the consequences of this kind of conceptualizations of genre in their research [see @calvotello_2021_novel;  @henny-krahmer_2023_genre]. 

Another major issue in the theory of genres that has significant relevance for computational approaches to genre is the question of whether genres manifest themselves as inherently textual properties of texts, or whether they are rather socially-constructed phenomena. This has direct implications for the question of whether or not approaches focusing only on textual properties rather than on contextual information are suitable for investigations of literary genre.^[This is an issue that has clear parallels to the situation in research on canonicity and prestige, see the chapter "What is Canonicity?" (@sec-what-canon).]  

As far as the description, theory and history of specific genres is concerned, this is quite obviously a large, important and dynamic domain within literary studies. Studies on specific genres and subgenres – such as the novel, the short story, the science fiction novel; such as drama, comedy or tragedy; the sonnet, etc. – are plentiful, whether in a specific literary period, across several periods, or in a theoretical perspective. Also, because individual genres can be defined and described at various levels – among them theme, style, form, setting, protagonist, plot or audience – investigations of all of these aspects can be relevant in a genre analysis. To give just some examples: genre is often defined at the level of formal, structural or stylistic characteristics, such as poetry in verse compared to narrative prose or dramatic dialogue interspersed with stage directions. However, theme is also a major aspect of genre and subgenre, as in the distinction between the romance novel (primarily about love and obstacles to love) as opposed to the science fiction novel (primarily about imaginary alternatives, based on scientific and social innovations, to human existence as we know it). Personnel, of course, can also play a role, as in the kinds of characters that are typical of tragedies as opposed to comedies. Then, setting can be relevant, as in the urban settings typical for crime fiction as opposed to the outer limits of civilization characteristic of many adventure novels. Many more examples for relevant aspects could be added here. 

For research in CLS, studies covering such aspects in various genres not only provide essential background information, but also raise research questions and offer hypotheses to investigate based on metadata or corpora. 

## Computational Genre Analysis 

Against this background, there are two levels at which different kinds of literary genre analysis can be distinguished, based on a distinction between various degrees of granularity: (a) At the level of the texts to be analyzed, where entire documents, chapters, paragraphs, pages or even sentences can be the object of attention. And (b) at the level of the genre categories, where broad genres (such as the distinction between narrative and dramatic texts), more specific subgenres (such as the distinction between comedy and tragedy, adventure novel and science-fiction novel), or even more fine-grained distinctions within subgenres (such as the distinction between detective fiction and hard-boiled crime fiction) may be investigated. Most research in CLS is focused, nowadays, at the second level of granularity.  

Another key distinction is whether the investigation of genre (a) starts from known genre assignments of texts and aims to discover features (of various types) that are characteristic of texts of each genre category (contrastive analysis), or whether (b) establishing the association between texts and genre categories is the principal task (e.g. classification tasks), or whether (c) any structure in the data that can be discovered is then checked for correlations with genre categories (e.g. clustering tasks). Mixed approaches are frequent, as there are investigations using some form of regression analysis. 

Finally, a large proportion of research is interested in genre not so much in order to attribute texts to genres or subgenres, or to identify general characteristics of given genres or subgenres, but is rather focused on texts belonging to one particular genre or subgenre category, where this category is accepted _a priori_. The focus in this case is rather to analyze some specific literary phenomenon within a corpus defined by its genre or subgenre. Additional research is either based on the results from such classification tasks, or uses alternative approaches to such classification tasks. 

Further details on the corpora used for genre analysis, on the kinds of annotations used, and on the methods of analysis used in selected research belonging to these different categories are provided in the following sections.

## References {.unnumbered .unlisted}

See [works cited and further readings](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_what-genre/library) for this chapter on Zotero. 

## Citation suggestion  {.unnumbered .unlisted}

Christof Schöch (2023): "What is Genre Analysis?". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/what-genre.html](https://methods.clsinfra.io/what-genre.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{schoch_2023_genre,
  title = {What is Genre Analysis?},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {Schöch, Christof},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/what-genre.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 

