# What is Literary History? {#sec-what-lithist}

_Artjoms Šeļa (Kraków)_

## Introduction

Literary history, unlike other topics in this survey, is not a single task (like authorship attribution) or an object of study that could easily make up its own field in cultural studies (genre, gender, canonicity). It can enclose all its neighbors (history of genre, history of gender in literature), or be tangential to them, if history is understood as historiography: adding facts and documents to the body of knowledge. To be able to write about literary history, it must be first framed in one way or another.

## Modes of literary history

Here, the focus is on the study of history in the sense of both Annales school and formalists. Fernand Braudel and colleagues saw the primary object of history in the study of change and continuity [see @legoff_2015_must]; formalists spoke of evolution of literature as an autonomous system, driven by forces that cannot be entirely reduced to social, political or economic currents (later this understanding was radically expanded by Bourdieu). In this light, the focus here is on the aspects of analyzing, inferring and evaluating _historical change_ in literature — change that can be linguistic, morphological, or social. _Analysis_ here mostly refers to detecting trends, trendlines and statistical models used in CLS to work with time. Inference points to methods of _anticipating_ historical relationships between texts, often based on intertextual analysis: through techniques of text reuse, calculation of distances and building trees. The _evaluation_ perspective describes attempts at historical generative models that try to replay history many times to see if baked-in assumptions about how things _may happen_ can hold in sandboxes — radically simplified bare-bones worlds. 

This perspective on literary history, of course, is quite specific and rooted in a certain vision of the main questions and methodologies. However, there are two modes of literary history that must be mentioned in this introduction, to better articulate what is not the primary focus of our survey (without excluding these perspectives completely).

The first mode, already mentioned above, is what can be called ‘historiographic’ — adding facts [@coker_2019_building] and opening access to collections [@fischer_2019_programmable; @schoch_2021_creating], contextualizing marginalized and forgotten authors [@wernimont_2011_possible; @borgo_2017_sustainable], doing explorative dives into the Archive [@forlini_2016_stuff], encoding texts in a standardized way, preparing editions and critical apparatus [@mann_2018_how], or connecting various strands of knowledge together via the semantic web [@gehrke_2016_biblissima; @schoch_2022_smart]. In addition to that, we see certain work in this mode as ‘reconstructive’ , because it makes visible things that were not visible or accessible before: simulating paths of Romantic journeys through the Lake district using elevation data [@murrieta-flores_2016_gis], modeling early modern theaters [@depaepe_2014_visualizing], or providing interactive software environments to stage historical plays [@roberts-smith_2013_visualizing; @roberts-smith_2013_visualising].

At the most general level, literary history is simply a _story_, a _narrative_. This is the second mode, in which scholars recover, piece together, challenge, or reinforce the _stories_ about literature. Computational methods is another way to gather evidence and argue about well-known problems: Black writers and Biblical discourse [@so_2018_race], representation of women novelists [@moravec_2021_feminist], pace of literary change and conflict for aesthetic dominance [@underwood_2019_we; @underwood_2019_distant], the rapid diffusion of third-person narration or free indirect discourse [@long_2021_values], the changing fates of various historical forms of the novel [@paige_2020_technologies], or long-term continuity in usage of poetic meters [@sela_2022_semantics]. This is a continuous and endless process of (re)writing the history, both at small and a large scales: it, of course, goes beyond any particular computational project, or specific text preservation / representation solution.

## References {.unnumbered .unlisted}

See [works cited and further readings](https://www.zotero.org/groups/5011419/cls_bibliography/tags/clsi_what-lihist/library) on Zotero. 

## Citation suggestion  {.unnumbered .unlisted}

Artjoms Šeļa (2023): "What is Literary History?". In: _Survey of Methods in Computational Literary Studies_ (= D 3.2: Series of Five Short Survey Papers on Methodological Issues). Edited by Christof Schöch, Julia Dudar, Evegniia Fileva. Trier: CLS INFRA. URL: [https://methods.clsinfra.io/what-lithist.html](https://methods.clsinfra.io/what-lithist.html), DOI: [10.5281/zenodo.7892112](https://doi.org/10.5281/zenodo.7892112). 

```
@incollection{sela_2023_lithist,
  title = {What is Literary History?},
  booktitle = {Survey of {{Methods}} in {{Computational 
  Literary Studies}} (= {{D}} 3.2: {{Series}} of {{Five Short 
  Survey Papers}} on {{Methodological Issues}})},
  author = {Šeļa, Artjoms},
  editor = {Schöch, Christof and Dudar, Julia and Fileva, Evgeniia},
  date = {2023},
  publisher = {{CLS INFRA}},
  location = {{Trier}},
  doi = {10.5281/zenodo.7892112},
  url = {https://methods.clsinfra.io/what-lithist.html},
  langid = {english}
}
```

License: [Creative Commons Attribution 4.0 International (CC BY)](https://creativecommons.org/licenses/by/4.0/). 

